from .sharedClass import SharedClass
from .extractClass import ExtractClass
from .subClasses import *

class Sentence(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data
		self.ner = ner(data['NER']) if data and 'NER' in data else None
		self.nlu = nlu(data['NLU']) if data and 'NLU' in data else None
		self.nlp = nlp(data['NLP']) if data and 'NLP' in data else None
		self.sentiment = sentiment(data['Sentiment']) if data and 'Sentiment' in data and 'list' in data['Sentiment'] else None
		self.emoticons = emoticons(data['emoticons']) if data and 'emoticons' in data else None
		self.parser_dependency = parser_dependency(data['parser_dependency']) if data and 'parser_dependency' in data else None
		self.postagger = postagger(data['postagger']) if data and 'postagger' in data else None
		self.sentence_acts = sentence_acts(data['sentence_acts']) if data and 'sentence_acts' in data else None
		self.coreference = coreference(data['coreference']) if data and 'coreference' in data else None
		self.data_global = data['global'] if data and 'global' in data else None

	def getByFilter(self, key, value, list=None):
		r = []
		l = list if list else self.data_global
		if not isinstance(l, type([])):
			return None
		for item in l:
			try:
				if '.' in key:
					if self.getNested(key, item) == value:
						r.append(item)
				else:
					if item[key] == value:
						r.append(item)
			except:
				pass
		return r



from .sharedClass import SharedClass
from .extractClass import ExtractClass

class ner(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

class nlu(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

class nlp(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

class sentiment_list(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

class sentiment_group(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

class sentiment(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data
		self.list = sentiment_list(data['list']) if 'list' in data else None
		self.group = sentiment_group(data['group']) if 'group' in data else None

class emoticons(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

	def getConfidence(self):
		r = []
		if self.data and 'confidence' in self.data:
			return self.data['confidence']
		return None

	def getPresent(self):
		r = []
		if self.data and 'emoticon' in self.data:
			for k in self.data['emoticon']:
				if self.data['emoticon'][k]:
					r.append(k)
		return r

class parser_dependency(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

	def getByRole(self, role):
		return self.getByFilter('dep', role)

class postagger():
	def __init__(self, data=None):
		self.data = data

	def get(self):
		return self.data

	def getByTag(self, tag):
		r = []
		if self.data:
			for item in self.data:
				if isinstance(tag, list):
					if item[1] in tag:
						r.append(item)
				else:
					if item[1] == tag:
						r.append(item)
		return r

class sentence_acts(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data

class coreference(SharedClass, ExtractClass):
	def __init__(self, data=None):
		self.data = data



class ExtractClass:
    def getDateItems(self):
        return self.getByFilter('type', 'date')

    def getDistanceItems(self):
        return self.getByFilter('type', 'distance')

    def getDurationItems(self):
        return self.getByFilter('type', 'duration')

    def getElectricPowerItems(self):
        return self.getByFilter('type', 'electric power')

    def getHexColorItems(self):
        return self.getByFilter('type', 'hex color')

    def getIntervalItems(self):
        return self.getByFilter('type', 'interval')

    def getIpItems(self):
        return self.getByFilter('type', 'ip')

    def getIpv6Items(self):
        return self.getByFilter('type', 'ipv6')

    def getLightIntensityItems(self):
        return self.getByFilter('type', 'light intensity')

    def getMailItems(self):
        return self.getByFilter('type', 'mail')

    def getMassItems(self):
        return self.getByFilter('type', 'mass')

    def getMassByVolumeItems(self):
        return self.getByFilter('type', 'mass by volume')

    def getMolItems(self):
        return self.getByFilter('type', 'mol')

    def getMoneyItems(self):
        return self.getByFilter('type', 'money')

    def getOrdinalItems(self):
        return self.getByFilter('type', 'ordinal')

    def getPercentItems(self):
        return self.getByFilter('type', 'percent')

    def getPhoneItems(self):
        return self.getByFilter('type', 'phone')

    def getPressureItems(self):
        return self.getByFilter('type', 'pressure')

    def getSetItems(self):
        return self.getByFilter('type', 'set')

    def getSpeedItems(self):
        return self.getByFilter('type', 'speed')

    def getStrengthItems(self):
        return self.getByFilter('type', 'strength')

    def getSurfaceItems(self):
        return self.getByFilter('type', 'surface')

    def getSurfaceTensionItems(self):
        return self.getByFilter('type', 'surface tension')

    def getTemperatureItems(self):
        return self.getByFilter('type', 'temperature')

    def getTimeItems(self):
        return self.getByFilter('type', 'time')

    def getUrlItems(self):
        return self.getByFilter('type', 'url')

    def getVoltageItems(self):
        return self.getByFilter('type', 'voltage')

    def getVolumeItems(self):
        return self.getByFilter('type', 'volume')

    def getHappinessItems(self):
        return self.getByFilter('type', 'happiness')

    def getSadnessItems(self):
        return self.getByFilter('type', 'sadness')

    def getFearItems(self):
        return self.getByFilter('type', 'fear')

    def getDisgustItems(self):
        return self.getByFilter('type', 'disgust')

    def getAngerItems(self):
        return self.getByFilter('type', 'anger')

    def getSurpriseItems(self):
        return self.getByFilter('type', 'surprise')

    def getJudgementItems(self):
        return self.getByFilter('type', 'judgement')



import json

class SharedClass:
	def __init__(self, data=None):
		pass
	def __str__(self):
		try:
			return json.dumps(self.data, indent=4, sort_keys=True)
		except:
			return str(self.data)

	def get(self):
		return self.data

	def set(self, data=None):
		try:
			self.data = data
			return True
		except:
			return False

	def getNested(self, key, obj):
		if not isinstance(obj, dict):
			return None
		keys = key.split('.')
		k = keys.pop(0)
		if k not in obj: return None
		obj = obj[k]
		key = ''
		if len(keys) > 0:
			for item in keys: key += item + '.'
			return self.getNested(key[:-1], obj)
		return obj

	def getByFilter(self, key, value, list=None):
		r = []
		l = list if list else self.data
		if not isinstance(l, type([])):
			print("Lettria SDK: \033[1;33;40mWARNING:\033[0;37;40m {}".format(
				"getByFilter() was called on something that does not contain a list format."
			))
			return None
		for item in l:
			try:
				if '.' in key:
					if self.getNested(key, item) == value:
						r.append(item)
				else:
					if item[key] == value:
						r.append(item)
			except:
				pass
		return r
